package com.caimei.mapper;

import com.caimei.model.po.ProductDetailInfoPo;
import com.caimei.model.po.UserSearchHistoryPo;
import com.caimei.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/4/22
 */
@Mapper
public interface ProductMapper {
    /**
     * 查询所有的轮播图
     *
     * @return
     */
    List<String> findImageAll();

    /**
     * 查询商品
     *
     * @param productName
     * @return
     */
    List<ProductVo> findProductList(@Param("productName") String productName);

    /**
     * 查询楼层商品
     *
     * @param productName
     * @param limitNum
     * @return
     */
    List<ProductVo> findFloorProductList(@Param("floorId") Integer floorId, @Param("productName") String productName, @Param("limitNum") Integer limitNum);

    /**
     * 查询进行中的活动
     *
     * @param productId
     * @return
     */
    Integer findActivityByProductId(Integer productId);

    /**
     * 活动阶梯价格
     *
     * @param activityId 活动id
     * @param productId  商品id
     * @return
     */
    List<ActivityLadderVo> findActivityLadder(@Param("activityId") Integer activityId, @Param("productId") Integer productId);

    /**
     * 查询商品详情
     *
     * @param productId
     * @return
     */
    ProductDetailsVo findProductByProductId(Integer productId);

    /**
     * 查询所有的商品图片
     *
     * @param productId
     * @return
     */
    List<String> findProductImages(Integer productId);

    /**
     * 查询详情信息
     *
     * @param productId
     * @return
     */
    ProductDetailInfoPo findProductDetail(Integer productId);

    /**
     * 查询分类名称
     *
     * @param bigTypeId
     * @param smallTypeId
     * @param tinyTypeId
     * @return
     */
    String findTypeName(@Param("bigTypeId") Integer bigTypeId, @Param("smallTypeId") Integer smallTypeId, @Param("tinyTypeId") Integer tinyTypeId);

    /**
     * 查询品牌名称
     *
     * @param brandId
     * @return
     */
    String findBrandName(Integer brandId);

    /**
     * 查询相关参数
     *
     * @param productId
     * @return
     */
    List<RelatedParametersVo> findParameters(Integer productId);

    /**
     * 查询历史记录
     *
     * @param userId 用户id
     * @param name   搜索关键词
     * @return
     */
    Integer findSearchHistory(@Param("userId") Integer userId, @Param("name") String name);

    /**
     * 修改关键词时间
     *
     * @param recordId
     */
    void updateHistoryByDate(Integer recordId);

    /**
     * 保存搜索历史记录
     *
     * @param history
     */
    void insertSearchHistory(UserSearchHistoryPo history);

    /**
     * 查询搜索历史记录
     *
     * @param userId
     * @return
     */
    List<String> searchHistory(Integer userId);

    /**
     * 删除多余的历史记录
     *
     * @param userId
     */
    void deleteHistoryByUserId(Integer userId);

    /**
     * 删除历史记录
     *
     * @param userId
     */
    void deleteHistory(Integer userId);

    /**
     * 查询分销者下所有活动
     *
     * @param userId
     * @return
     */
    List<HeHeActivityVo> findActivityAll(Integer userId);

    /**
     * 查询活动详情图片
     *
     * @param activityId
     * @return
     */
    String findActivityById(Integer activityId);

    /**
     * 查询活动商品
     *
     * @param userId     分销者id
     * @param activityId 活动id
     * @return
     */
    List<ProductVo> findActivityProduct(@Param("userId") Integer userId, @Param("activityId") Integer activityId);


    /**
     * 获取所有商品楼层
     * @return
     */
    List<FloorVo> findAllFloor();



    FloorVo findFloorById(Integer floorId);
}
